@@ -241,8 +241,12 @@ def render_protein_card(entity, index):
         )
 
         cols = st.columns([2, 2, 6])
-        # cols[0].button("+ Add MSA", key=f"msa_{index}")
         cols[0].toggle(
+            "Add MSA",
+            key=f"msa_{index}",
+            help="Whether to add a multiple sequence alignment",
+        )
+        cols[1].toggle(
             "Cyclic",
             key=f"cyc_prot_{index}",
             help="Whether the polymer forms a cyclic structure",
@@ -347,11 +351,15 @@ def gather_submission_data():
     if st.session_state.get("entity_name"):
         submission["name"] = st.session_state.entity_name
 
+    if st.session_state.get("diffusion_samples"):
+        submission["diffusion_samples"] = st.session_state.diffusion_samples
+
     for i, entity in enumerate(st.session_state.entities):
         entity_data = {"type": entity["type"], "chain_id": entity["chain_id"]}
 
         if entity["type"] == "Protein":
             entity_data["sequence"] = st.session_state.get(f"seq_prot_{i}", "")
+            entity_data["msa"] = st.session_state.get(f"msa_{i}", False)
             entity_data["cyclic"] = st.session_state.get(f"cyc_prot_{i}", False)
             mods = []
             for mod_i in range(len(entity.get("modifications", []))):
@@ -478,7 +486,14 @@ with title_cols[1]:
 st.text_input(
     "Entity Name (Optional)", key="entity_name", placeholder="e.g., Test Complex"
 )
-
+st.number_input(
+    "How many structure samples you want to get?",
+    min_value=1,
+    max_value=5,
+    value=1,
+    step=1,
+    key="diffusion_samples",
+)
 # --- Example Dialog Logic ---
 if st.session_state.get("show_examples_dialog", False):
     st.dialog("Select an Example")
